
USETEXTLINKS = 1
STARTALLOPEN = 0
ICONPATH = 'icons/'

aux0 = gFld("Variables", "varsRightFrame.html")
foldersTree = aux0
aux1 = insFld(aux0, gFld("Calculation Modes", "vars/Calculation_Modes.html#Calculation_Modes"))
insDoc(aux1, gLnk("R", "CalculationMode", "vars/Calculation_Modes.html#CalculationMode"))
aux2 = insFld(aux1, gFld("Geometry Optimization", "vars/Calculation_Modes.html#Calculation_Modes::Geometry_Optimization"))
insDoc(aux2, gLnk("R", "GOCenter", "vars/Calculation_Modes.html#GOCenter"))
insDoc(aux2, gLnk("R", "GOFireIntegrator", "vars/Calculation_Modes.html#GOFireIntegrator"))
insDoc(aux2, gLnk("R", "GOFireMass", "vars/Calculation_Modes.html#GOFireMass"))
insDoc(aux2, gLnk("R", "GOLineTol", "vars/Calculation_Modes.html#GOLineTol"))
insDoc(aux2, gLnk("R", "GOMaxIter", "vars/Calculation_Modes.html#GOMaxIter"))
insDoc(aux2, gLnk("R", "GOMethod", "vars/Calculation_Modes.html#GOMethod"))
insDoc(aux2, gLnk("R", "GOMinimumMove", "vars/Calculation_Modes.html#GOMinimumMove"))
insDoc(aux2, gLnk("R", "GOObjective", "vars/Calculation_Modes.html#GOObjective"))
insDoc(aux2, gLnk("R", "GOStep", "vars/Calculation_Modes.html#GOStep"))
insDoc(aux2, gLnk("R", "GOTolerance", "vars/Calculation_Modes.html#GOTolerance"))
aux2 = insFld(aux1, gFld("Invert KS", "vars/Calculation_Modes.html#Calculation_Modes::Invert_KS"))
insDoc(aux2, gLnk("R", "InvertKSConvAbsDens", "vars/Calculation_Modes.html#InvertKSConvAbsDens"))
insDoc(aux2, gLnk("R", "InvertKSGodbyMu", "vars/Calculation_Modes.html#InvertKSGodbyMu"))
insDoc(aux2, gLnk("R", "InvertKSGodbyPower", "vars/Calculation_Modes.html#InvertKSGodbyPower"))
insDoc(aux2, gLnk("R", "InvertKSMaxIter", "vars/Calculation_Modes.html#InvertKSMaxIter"))
insDoc(aux2, gLnk("R", "InvertKSStellaAlpha", "vars/Calculation_Modes.html#InvertKSStellaAlpha"))
insDoc(aux2, gLnk("R", "InvertKSStellaBeta", "vars/Calculation_Modes.html#InvertKSStellaBeta"))
insDoc(aux2, gLnk("R", "InvertKSTargetDensity", "vars/Calculation_Modes.html#InvertKSTargetDensity"))
insDoc(aux2, gLnk("R", "InvertKSVerbosity", "vars/Calculation_Modes.html#InvertKSVerbosity"))
insDoc(aux2, gLnk("R", "InvertKSmethod", "vars/Calculation_Modes.html#InvertKSmethod"))
insDoc(aux2, gLnk("R", "KSInversionAsymptotics", "vars/Calculation_Modes.html#KSInversionAsymptotics"))
insDoc(aux2, gLnk("R", "KSInversionLevel", "vars/Calculation_Modes.html#KSInversionLevel"))
aux2 = insFld(aux1, gFld("Optimal Control", "vars/Calculation_Modes.html#Calculation_Modes::Optimal_Control"))
insDoc(aux2, gLnk("R", "OCTCheckGradient", "vars/Calculation_Modes.html#OCTCheckGradient"))
insDoc(aux2, gLnk("R", "OCTClassicalTarget", "vars/Calculation_Modes.html#OCTClassicalTarget"))
insDoc(aux2, gLnk("R", "OCTControlFunctionOmegaMax", "vars/Calculation_Modes.html#OCTControlFunctionOmegaMax"))
insDoc(aux2, gLnk("R", "OCTControlFunctionRepresentation", "vars/Calculation_Modes.html#OCTControlFunctionRepresentation"))
insDoc(aux2, gLnk("R", "OCTControlFunctionType", "vars/Calculation_Modes.html#OCTControlFunctionType"))
insDoc(aux2, gLnk("R", "OCTCurrentFunctional", "vars/Calculation_Modes.html#OCTCurrentFunctional"))
insDoc(aux2, gLnk("R", "OCTCurrentWeight", "vars/Calculation_Modes.html#OCTCurrentWeight"))
insDoc(aux2, gLnk("R", "OCTDelta", "vars/Calculation_Modes.html#OCTDelta"))
insDoc(aux2, gLnk("R", "OCTDirectStep", "vars/Calculation_Modes.html#OCTDirectStep"))
insDoc(aux2, gLnk("R", "OCTDoubleCheck", "vars/Calculation_Modes.html#OCTDoubleCheck"))
insDoc(aux2, gLnk("R", "OCTDumpIntermediate", "vars/Calculation_Modes.html#OCTDumpIntermediate"))
insDoc(aux2, gLnk("R", "OCTEps", "vars/Calculation_Modes.html#OCTEps"))
insDoc(aux2, gLnk("R", "OCTEta", "vars/Calculation_Modes.html#OCTEta"))
insDoc(aux2, gLnk("R", "OCTExcludedStates", "vars/Calculation_Modes.html#OCTExcludedStates"))
insDoc(aux2, gLnk("R", "OCTFilter", "vars/Calculation_Modes.html#OCTFilter"))
insDoc(aux2, gLnk("R", "OCTFixFluenceTo", "vars/Calculation_Modes.html#OCTFixFluenceTo"))
insDoc(aux2, gLnk("R", "OCTFixInitialFluence", "vars/Calculation_Modes.html#OCTFixInitialFluence"))
insDoc(aux2, gLnk("R", "OCTHarmonicWeight", "vars/Calculation_Modes.html#OCTHarmonicWeight"))
insDoc(aux2, gLnk("R", "OCTInitialState", "vars/Calculation_Modes.html#OCTInitialState"))
insDoc(aux2, gLnk("R", "OCTInitialTransformStates", "vars/Calculation_Modes.html#OCTInitialTransformStates"))
insDoc(aux2, gLnk("R", "OCTInitialUserdefined", "vars/Calculation_Modes.html#OCTInitialUserdefined"))
insDoc(aux2, gLnk("R", "OCTLaserEnvelope", "vars/Calculation_Modes.html#OCTLaserEnvelope"))
insDoc(aux2, gLnk("R", "OCTLocalTarget", "vars/Calculation_Modes.html#OCTLocalTarget"))
insDoc(aux2, gLnk("R", "OCTMaxIter", "vars/Calculation_Modes.html#OCTMaxIter"))
insDoc(aux2, gLnk("R", "OCTMomentumDerivatives", "vars/Calculation_Modes.html#OCTMomentumDerivatives"))
insDoc(aux2, gLnk("R", "OCTNumberCheckPoints", "vars/Calculation_Modes.html#OCTNumberCheckPoints"))
insDoc(aux2, gLnk("R", "OCTOptimizeHarmonicSpectrum", "vars/Calculation_Modes.html#OCTOptimizeHarmonicSpectrum"))
insDoc(aux2, gLnk("R", "OCTPenalty", "vars/Calculation_Modes.html#OCTPenalty"))
insDoc(aux2, gLnk("R", "OCTPositionDerivatives", "vars/Calculation_Modes.html#OCTPositionDerivatives"))
insDoc(aux2, gLnk("R", "OCTRandomInitialGuess", "vars/Calculation_Modes.html#OCTRandomInitialGuess"))
insDoc(aux2, gLnk("R", "OCTScheme", "vars/Calculation_Modes.html#OCTScheme"))
insDoc(aux2, gLnk("R", "OCTSpatialCurrWeight", "vars/Calculation_Modes.html#OCTSpatialCurrWeight"))
insDoc(aux2, gLnk("R", "OCTStartIterCurrTg", "vars/Calculation_Modes.html#OCTStartIterCurrTg"))
insDoc(aux2, gLnk("R", "OCTTargetDensity", "vars/Calculation_Modes.html#OCTTargetDensity"))
insDoc(aux2, gLnk("R", "OCTTargetDensityFromState", "vars/Calculation_Modes.html#OCTTargetDensityFromState"))
insDoc(aux2, gLnk("R", "OCTTargetOperator", "vars/Calculation_Modes.html#OCTTargetOperator"))
insDoc(aux2, gLnk("R", "OCTTargetSpin", "vars/Calculation_Modes.html#OCTTargetSpin"))
insDoc(aux2, gLnk("R", "OCTTargetTransformStates", "vars/Calculation_Modes.html#OCTTargetTransformStates"))
insDoc(aux2, gLnk("R", "OCTTargetUserdefined", "vars/Calculation_Modes.html#OCTTargetUserdefined"))
insDoc(aux2, gLnk("R", "OCTTdTarget", "vars/Calculation_Modes.html#OCTTdTarget"))
insDoc(aux2, gLnk("R", "OCTVelocityDerivatives", "vars/Calculation_Modes.html#OCTVelocityDerivatives"))
insDoc(aux2, gLnk("R", "OCTVelocityTarget", "vars/Calculation_Modes.html#OCTVelocityTarget"))
aux2 = insFld(aux1, gFld("Unoccupied States", "vars/Calculation_Modes.html#Calculation_Modes::Unoccupied_States"))
insDoc(aux2, gLnk("R", "UnoccShowOccStates", "vars/Calculation_Modes.html#UnoccShowOccStates"))
aux1 = insFld(aux0, gFld("Execution", "vars/Execution.html#Execution"))
insDoc(aux1, gLnk("R", "FromScratch", "vars/Execution.html#FromScratch"))
insDoc(aux1, gLnk("R", "Splines", "vars/Execution.html#Splines"))
aux2 = insFld(aux1, gFld("Debug", "vars/Execution.html#Execution::Debug"))
insDoc(aux2, gLnk("R", "Debug", "vars/Execution.html#Debug"))
insDoc(aux2, gLnk("R", "ExperimentalFeatures", "vars/Execution.html#ExperimentalFeatures"))
insDoc(aux2, gLnk("R", "ForceComplex", "vars/Execution.html#ForceComplex"))
insDoc(aux2, gLnk("R", "MPIDebugHook", "vars/Execution.html#MPIDebugHook"))
insDoc(aux2, gLnk("R", "ReportMemory", "vars/Execution.html#ReportMemory"))
aux2 = insFld(aux1, gFld("IO", "vars/Execution.html#Execution::IO"))
insDoc(aux2, gLnk("R", "FlushMessages", "vars/Execution.html#FlushMessages"))
insDoc(aux2, gLnk("R", "RestartOptions", "vars/Execution.html#RestartOptions"))
insDoc(aux2, gLnk("R", "RestartWrite", "vars/Execution.html#RestartWrite"))
insDoc(aux2, gLnk("R", "RestartWriteInterval", "vars/Execution.html#RestartWriteInterval"))
insDoc(aux2, gLnk("R", "WorkDir", "vars/Execution.html#WorkDir"))
insDoc(aux2, gLnk("R", "stderr", "vars/Execution.html#stderr"))
insDoc(aux2, gLnk("R", "stdout", "vars/Execution.html#stdout"))
aux2 = insFld(aux1, gFld("OpenCL", "vars/Execution.html#Execution::OpenCL"))
insDoc(aux2, gLnk("R", "DisableOpenCL", "vars/Execution.html#DisableOpenCL"))
insDoc(aux2, gLnk("R", "OpenCLBenchmark", "vars/Execution.html#OpenCLBenchmark"))
insDoc(aux2, gLnk("R", "OpenCLDevice", "vars/Execution.html#OpenCLDevice"))
insDoc(aux2, gLnk("R", "OpenCLPlatform", "vars/Execution.html#OpenCLPlatform"))
aux2 = insFld(aux1, gFld("Optimization", "vars/Execution.html#Execution::Optimization"))
insDoc(aux2, gLnk("R", "MemoryLimit", "vars/Execution.html#MemoryLimit"))
insDoc(aux2, gLnk("R", "MeshBlockSize", "vars/Execution.html#MeshBlockSize"))
insDoc(aux2, gLnk("R", "MeshOrder", "vars/Execution.html#MeshOrder"))
insDoc(aux2, gLnk("R", "NLOperatorCompactBoundaries", "vars/Execution.html#NLOperatorCompactBoundaries"))
insDoc(aux2, gLnk("R", "OperateComplex", "vars/Execution.html#OperateComplex"))
insDoc(aux2, gLnk("R", "OperateComplexSingle", "vars/Execution.html#OperateComplexSingle"))
insDoc(aux2, gLnk("R", "OperateDouble", "vars/Execution.html#OperateDouble"))
insDoc(aux2, gLnk("R", "OperateOpenCL", "vars/Execution.html#OperateOpenCL"))
insDoc(aux2, gLnk("R", "OperateSingle", "vars/Execution.html#OperateSingle"))
insDoc(aux2, gLnk("R", "ProfilingAllNodes", "vars/Execution.html#ProfilingAllNodes"))
insDoc(aux2, gLnk("R", "ProfilingMode", "vars/Execution.html#ProfilingMode"))
insDoc(aux2, gLnk("R", "StatesBlockSize", "vars/Execution.html#StatesBlockSize"))
insDoc(aux2, gLnk("R", "StatesCLDeviceMemory", "vars/Execution.html#StatesCLDeviceMemory"))
insDoc(aux2, gLnk("R", "StatesPack", "vars/Execution.html#StatesPack"))
aux2 = insFld(aux1, gFld("Parallelization", "vars/Execution.html#Execution::Parallelization"))
insDoc(aux2, gLnk("R", "MeshPartition", "vars/Execution.html#MeshPartition"))
insDoc(aux2, gLnk("R", "MeshPartitionPackage", "vars/Execution.html#MeshPartitionPackage"))
insDoc(aux2, gLnk("R", "MeshPartitionStencil", "vars/Execution.html#MeshPartitionStencil"))
insDoc(aux2, gLnk("R", "MeshPartitionVirtualSize", "vars/Execution.html#MeshPartitionVirtualSize"))
insDoc(aux2, gLnk("R", "MeshUseTopology", "vars/Execution.html#MeshUseTopology"))
insDoc(aux2, gLnk("R", "ParDomains", "vars/Execution.html#ParDomains"))
insDoc(aux2, gLnk("R", "ParKPoints", "vars/Execution.html#ParKPoints"))
insDoc(aux2, gLnk("R", "ParOther", "vars/Execution.html#ParOther"))
insDoc(aux2, gLnk("R", "ParStates", "vars/Execution.html#ParStates"))
insDoc(aux2, gLnk("R", "ParallelizationNumberSlaves", "vars/Execution.html#ParallelizationNumberSlaves"))
insDoc(aux2, gLnk("R", "ParallelizationOfDerivatives", "vars/Execution.html#ParallelizationOfDerivatives"))
insDoc(aux2, gLnk("R", "ParallelizationPoissonAllNodes", "vars/Execution.html#ParallelizationPoissonAllNodes"))
insDoc(aux2, gLnk("R", "PartitionPrint", "vars/Execution.html#PartitionPrint"))
insDoc(aux2, gLnk("R", "ScaLAPACKCompatible", "vars/Execution.html#ScaLAPACKCompatible"))
insDoc(aux2, gLnk("R", "XCParallel", "vars/Execution.html#XCParallel"))
aux2 = insFld(aux1, gFld("Symmetries", "vars/Execution.html#Execution::Symmetries"))
insDoc(aux2, gLnk("R", "SymmetriesCompute", "vars/Execution.html#SymmetriesCompute"))
aux2 = insFld(aux1, gFld("Units", "vars/Execution.html#Execution::Units"))
insDoc(aux2, gLnk("R", "Units", "vars/Execution.html#Units"))
insDoc(aux2, gLnk("R", "UnitsOutput", "vars/Execution.html#UnitsOutput"))
insDoc(aux2, gLnk("R", "UnitsXYZFiles", "vars/Execution.html#UnitsXYZFiles"))
aux1 = insFld(aux0, gFld("Hamiltonian", "vars/Hamiltonian.html#Hamiltonian"))
insDoc(aux1, gLnk("R", "CalculateSelfInducedMagneticField", "vars/Hamiltonian.html#CalculateSelfInducedMagneticField"))
insDoc(aux1, gLnk("R", "ClassicalPotential", "vars/Hamiltonian.html#ClassicalPotential"))
insDoc(aux1, gLnk("R", "CurrentDensity", "vars/Hamiltonian.html#CurrentDensity"))
insDoc(aux1, gLnk("R", "EwaldAlpha", "vars/Hamiltonian.html#EwaldAlpha"))
insDoc(aux1, gLnk("R", "FilterPotentials", "vars/Hamiltonian.html#FilterPotentials"))
insDoc(aux1, gLnk("R", "ForceTotalEnforce", "vars/Hamiltonian.html#ForceTotalEnforce"))
insDoc(aux1, gLnk("R", "GaugeFieldDelay", "vars/Hamiltonian.html#GaugeFieldDelay"))
insDoc(aux1, gLnk("R", "GaugeFieldDynamics", "vars/Hamiltonian.html#GaugeFieldDynamics"))
insDoc(aux1, gLnk("R", "GaugeFieldPropagate", "vars/Hamiltonian.html#GaugeFieldPropagate"))
insDoc(aux1, gLnk("R", "GaugeVectorField", "vars/Hamiltonian.html#GaugeVectorField"))
insDoc(aux1, gLnk("R", "GyromagneticRatio", "vars/Hamiltonian.html#GyromagneticRatio"))
insDoc(aux1, gLnk("R", "IgnoreExternalIons", "vars/Hamiltonian.html#IgnoreExternalIons"))
insDoc(aux1, gLnk("R", "MassScaling", "vars/Hamiltonian.html#MassScaling"))
insDoc(aux1, gLnk("R", "ParticleMass", "vars/Hamiltonian.html#ParticleMass"))
insDoc(aux1, gLnk("R", "RashbaSpinOrbitCoupling", "vars/Hamiltonian.html#RashbaSpinOrbitCoupling"))
insDoc(aux1, gLnk("R", "RelativisticCorrection", "vars/Hamiltonian.html#RelativisticCorrection"))
insDoc(aux1, gLnk("R", "SCDMCutoffRadius", "vars/Hamiltonian.html#SCDMCutoffRadius"))
insDoc(aux1, gLnk("R", "SCDM_EXX", "vars/Hamiltonian.html#SCDM_EXX"))
insDoc(aux1, gLnk("R", "SCDM_verbose", "vars/Hamiltonian.html#SCDM_verbose"))
insDoc(aux1, gLnk("R", "SOStrength", "vars/Hamiltonian.html#SOStrength"))
insDoc(aux1, gLnk("R", "StaticElectricField", "vars/Hamiltonian.html#StaticElectricField"))
insDoc(aux1, gLnk("R", "StaticMagneticField", "vars/Hamiltonian.html#StaticMagneticField"))
insDoc(aux1, gLnk("R", "StaticMagneticField2DGauge", "vars/Hamiltonian.html#StaticMagneticField2DGauge"))
insDoc(aux1, gLnk("R", "TheoryLevel", "vars/Hamiltonian.html#TheoryLevel"))
insDoc(aux1, gLnk("R", "TimeZero", "vars/Hamiltonian.html#TimeZero"))
aux2 = insFld(aux1, gFld("ComplexScaling", "vars/Hamiltonian.html#Hamiltonian::ComplexScaling"))
insDoc(aux2, gLnk("R", "ComplexScaling", "vars/Hamiltonian.html#ComplexScaling"))
insDoc(aux2, gLnk("R", "ComplexScalingAlpha", "vars/Hamiltonian.html#ComplexScalingAlpha"))
insDoc(aux2, gLnk("R", "ComplexScalingAlphaLeft", "vars/Hamiltonian.html#ComplexScalingAlphaLeft"))
insDoc(aux2, gLnk("R", "ComplexScalingLocalizationRadius", "vars/Hamiltonian.html#ComplexScalingLocalizationRadius"))
insDoc(aux2, gLnk("R", "ComplexScalingLocalizationThreshold", "vars/Hamiltonian.html#ComplexScalingLocalizationThreshold"))
insDoc(aux2, gLnk("R", "ComplexScalingLocalizedStates", "vars/Hamiltonian.html#ComplexScalingLocalizedStates"))
insDoc(aux2, gLnk("R", "ComplexScalingPenalizationFactor", "vars/Hamiltonian.html#ComplexScalingPenalizationFactor"))
insDoc(aux2, gLnk("R", "ComplexScalingRotateSpectrum", "vars/Hamiltonian.html#ComplexScalingRotateSpectrum"))
insDoc(aux2, gLnk("R", "ComplexScalingTheta", "vars/Hamiltonian.html#ComplexScalingTheta"))
aux2 = insFld(aux1, gFld("PCM", "vars/Hamiltonian.html#Hamiltonian::PCM"))
insDoc(aux2, gLnk("R", "PCMCalcMethod", "vars/Hamiltonian.html#PCMCalcMethod"))
insDoc(aux2, gLnk("R", "PCMCalculation", "vars/Hamiltonian.html#PCMCalculation"))
insDoc(aux2, gLnk("R", "PCMCavity", "vars/Hamiltonian.html#PCMCavity"))
insDoc(aux2, gLnk("R", "PCMChargeSmearNN", "vars/Hamiltonian.html#PCMChargeSmearNN"))
insDoc(aux2, gLnk("R", "PCMDynamicEpsilon", "vars/Hamiltonian.html#PCMDynamicEpsilon"))
insDoc(aux2, gLnk("R", "PCMGamessBenchmark", "vars/Hamiltonian.html#PCMGamessBenchmark"))
insDoc(aux2, gLnk("R", "PCMQtotTol", "vars/Hamiltonian.html#PCMQtotTol"))
insDoc(aux2, gLnk("R", "PCMRadiusScaling", "vars/Hamiltonian.html#PCMRadiusScaling"))
insDoc(aux2, gLnk("R", "PCMRenormCharges", "vars/Hamiltonian.html#PCMRenormCharges"))
insDoc(aux2, gLnk("R", "PCMSmearingFactor", "vars/Hamiltonian.html#PCMSmearingFactor"))
insDoc(aux2, gLnk("R", "PCMSpheresOnH", "vars/Hamiltonian.html#PCMSpheresOnH"))
insDoc(aux2, gLnk("R", "PCMStaticEpsilon", "vars/Hamiltonian.html#PCMStaticEpsilon"))
insDoc(aux2, gLnk("R", "PCMTessSubdivider", "vars/Hamiltonian.html#PCMTessSubdivider"))
insDoc(aux2, gLnk("R", "PCMUpdateIter", "vars/Hamiltonian.html#PCMUpdateIter"))
insDoc(aux2, gLnk("R", "PCMVdWRadii", "vars/Hamiltonian.html#PCMVdWRadii"))
aux2 = insFld(aux1, gFld("Poisson", "vars/Hamiltonian.html#Hamiltonian::Poisson"))
insDoc(aux2, gLnk("R", "AlphaFMM", "vars/Hamiltonian.html#AlphaFMM"))
insDoc(aux2, gLnk("R", "DeltaEFMM", "vars/Hamiltonian.html#DeltaEFMM"))
insDoc(aux2, gLnk("R", "Poisson1DSoftCoulombParam", "vars/Hamiltonian.html#Poisson1DSoftCoulombParam"))
insDoc(aux2, gLnk("R", "PoissonCutoffRadius", "vars/Hamiltonian.html#PoissonCutoffRadius"))
insDoc(aux2, gLnk("R", "PoissonFFTKernel", "vars/Hamiltonian.html#PoissonFFTKernel"))
insDoc(aux2, gLnk("R", "PoissonSolver", "vars/Hamiltonian.html#PoissonSolver"))
insDoc(aux2, gLnk("R", "PoissonSolverBoundaries", "vars/Hamiltonian.html#PoissonSolverBoundaries"))
insDoc(aux2, gLnk("R", "PoissonSolverMaxIter", "vars/Hamiltonian.html#PoissonSolverMaxIter"))
insDoc(aux2, gLnk("R", "PoissonSolverMaxMultipole", "vars/Hamiltonian.html#PoissonSolverMaxMultipole"))
insDoc(aux2, gLnk("R", "PoissonSolverNodes", "vars/Hamiltonian.html#PoissonSolverNodes"))
insDoc(aux2, gLnk("R", "PoissonSolverThreshold", "vars/Hamiltonian.html#PoissonSolverThreshold"))
aux3 = insFld(aux2, gFld("ISF", "vars/Hamiltonian.html#Hamiltonian::Poisson::ISF"))
insDoc(aux3, gLnk("R", "PoissonSolverISFParallelData", "vars/Hamiltonian.html#PoissonSolverISFParallelData"))
aux3 = insFld(aux2, gFld("Multigrid", "vars/Hamiltonian.html#Hamiltonian::Poisson::Multigrid"))
insDoc(aux3, gLnk("R", "PoissonSolverMGMaxCycles", "vars/Hamiltonian.html#PoissonSolverMGMaxCycles"))
insDoc(aux3, gLnk("R", "PoissonSolverMGPostsmoothingSteps", "vars/Hamiltonian.html#PoissonSolverMGPostsmoothingSteps"))
insDoc(aux3, gLnk("R", "PoissonSolverMGPresmoothingSteps", "vars/Hamiltonian.html#PoissonSolverMGPresmoothingSteps"))
insDoc(aux3, gLnk("R", "PoissonSolverMGRelaxationFactor", "vars/Hamiltonian.html#PoissonSolverMGRelaxationFactor"))
insDoc(aux3, gLnk("R", "PoissonSolverMGRelaxationMethod", "vars/Hamiltonian.html#PoissonSolverMGRelaxationMethod"))
insDoc(aux3, gLnk("R", "PoissonSolverMGRestrictionMethod", "vars/Hamiltonian.html#PoissonSolverMGRestrictionMethod"))
aux2 = insFld(aux1, gFld("Subsystems", "vars/Hamiltonian.html#Hamiltonian::Subsystems"))
insDoc(aux2, gLnk("R", "TnaddFactor", "vars/Hamiltonian.html#TnaddFactor"))
insDoc(aux2, gLnk("R", "TnaddFunctional", "vars/Hamiltonian.html#TnaddFunctional"))
insDoc(aux2, gLnk("R", "TnaddPolarized", "vars/Hamiltonian.html#TnaddPolarized"))
aux2 = insFld(aux1, gFld("XC", "vars/Hamiltonian.html#Hamiltonian::XC"))
insDoc(aux2, gLnk("R", "Interaction1D", "vars/Hamiltonian.html#Interaction1D"))
insDoc(aux2, gLnk("R", "Interaction1DScreening", "vars/Hamiltonian.html#Interaction1DScreening"))
insDoc(aux2, gLnk("R", "LB94_modified", "vars/Hamiltonian.html#LB94_modified"))
insDoc(aux2, gLnk("R", "LB94_threshold", "vars/Hamiltonian.html#LB94_threshold"))
insDoc(aux2, gLnk("R", "OEPLevel", "vars/Hamiltonian.html#OEPLevel"))
insDoc(aux2, gLnk("R", "OEPMixing", "vars/Hamiltonian.html#OEPMixing"))
insDoc(aux2, gLnk("R", "SICCorrection", "vars/Hamiltonian.html#SICCorrection"))
insDoc(aux2, gLnk("R", "VDWCorrection", "vars/Hamiltonian.html#VDWCorrection"))
insDoc(aux2, gLnk("R", "VDWSelfConsistent", "vars/Hamiltonian.html#VDWSelfConsistent"))
insDoc(aux2, gLnk("R", "XCFunctional", "vars/Hamiltonian.html#XCFunctional"))
insDoc(aux2, gLnk("R", "XCKernel", "vars/Hamiltonian.html#XCKernel"))
insDoc(aux2, gLnk("R", "XCKernelLRCAlpha", "vars/Hamiltonian.html#XCKernelLRCAlpha"))
insDoc(aux2, gLnk("R", "XCUseGaugeIndependentKED", "vars/Hamiltonian.html#XCUseGaugeIndependentKED"))
insDoc(aux2, gLnk("R", "Xalpha", "vars/Hamiltonian.html#Xalpha"))
insDoc(aux2, gLnk("R", "libvdwxcDebug", "vars/Hamiltonian.html#libvdwxcDebug"))
insDoc(aux2, gLnk("R", "libvdwxcMode", "vars/Hamiltonian.html#libvdwxcMode"))
insDoc(aux2, gLnk("R", "libvdwxcVDWFactor", "vars/Hamiltonian.html#libvdwxcVDWFactor"))
aux3 = insFld(aux2, gFld("DensityCorrection", "vars/Hamiltonian.html#Hamiltonian::XC::DensityCorrection"))
insDoc(aux3, gLnk("R", "XCDensityCorrection", "vars/Hamiltonian.html#XCDensityCorrection"))
insDoc(aux3, gLnk("R", "XCDensityCorrectionCutoff", "vars/Hamiltonian.html#XCDensityCorrectionCutoff"))
insDoc(aux3, gLnk("R", "XCDensityCorrectionMinimum", "vars/Hamiltonian.html#XCDensityCorrectionMinimum"))
insDoc(aux3, gLnk("R", "XCDensityCorrectionNormalize", "vars/Hamiltonian.html#XCDensityCorrectionNormalize"))
insDoc(aux3, gLnk("R", "XCDensityCorrectionOptimize", "vars/Hamiltonian.html#XCDensityCorrectionOptimize"))
aux1 = insFld(aux0, gFld("Linear Response", "vars/Linear_Response.html#Linear_Response"))
insDoc(aux1, gLnk("R", "MagneticGaugeCorrection", "vars/Linear_Response.html#MagneticGaugeCorrection"))
insDoc(aux1, gLnk("R", "ResponseMethod", "vars/Linear_Response.html#ResponseMethod"))
aux2 = insFld(aux1, gFld("Casida", "vars/Linear_Response.html#Linear_Response::Casida"))
insDoc(aux2, gLnk("R", "CasidaCalcForces", "vars/Linear_Response.html#CasidaCalcForces"))
insDoc(aux2, gLnk("R", "CasidaCalcForcesKernel", "vars/Linear_Response.html#CasidaCalcForcesKernel"))
insDoc(aux2, gLnk("R", "CasidaCalcForcesSCF", "vars/Linear_Response.html#CasidaCalcForcesSCF"))
insDoc(aux2, gLnk("R", "CasidaCalcTriplet", "vars/Linear_Response.html#CasidaCalcTriplet"))
insDoc(aux2, gLnk("R", "CasidaHermitianConjugate", "vars/Linear_Response.html#CasidaHermitianConjugate"))
insDoc(aux2, gLnk("R", "CasidaKSEnergyWindow", "vars/Linear_Response.html#CasidaKSEnergyWindow"))
insDoc(aux2, gLnk("R", "CasidaKohnShamStates", "vars/Linear_Response.html#CasidaKohnShamStates"))
insDoc(aux2, gLnk("R", "CasidaMomentumTransfer", "vars/Linear_Response.html#CasidaMomentumTransfer"))
insDoc(aux2, gLnk("R", "CasidaQuadratureOrder", "vars/Linear_Response.html#CasidaQuadratureOrder"))
insDoc(aux2, gLnk("R", "CasidaTheoryLevel", "vars/Linear_Response.html#CasidaTheoryLevel"))
insDoc(aux2, gLnk("R", "CasidaTransitionDensities", "vars/Linear_Response.html#CasidaTransitionDensities"))
aux2 = insFld(aux1, gFld("KdotP", "vars/Linear_Response.html#Linear_Response::KdotP"))
insDoc(aux2, gLnk("R", "KdotPCalcSecondOrder", "vars/Linear_Response.html#KdotPCalcSecondOrder"))
insDoc(aux2, gLnk("R", "KdotPCalculateEffectiveMasses", "vars/Linear_Response.html#KdotPCalculateEffectiveMasses"))
insDoc(aux2, gLnk("R", "KdotPEta", "vars/Linear_Response.html#KdotPEta"))
insDoc(aux2, gLnk("R", "KdotPOccupiedSolutionMethod", "vars/Linear_Response.html#KdotPOccupiedSolutionMethod"))
insDoc(aux2, gLnk("R", "KdotPUseNonLocalPseudopotential", "vars/Linear_Response.html#KdotPUseNonLocalPseudopotential"))
insDoc(aux2, gLnk("R", "KdotPVelMethod", "vars/Linear_Response.html#KdotPVelMethod"))
aux2 = insFld(aux1, gFld("Polarizabilities", "vars/Linear_Response.html#Linear_Response::Polarizabilities"))
insDoc(aux2, gLnk("R", "BornChargeSumRuleCorrection", "vars/Linear_Response.html#BornChargeSumRuleCorrection"))
insDoc(aux2, gLnk("R", "EMCalcBornCharges", "vars/Linear_Response.html#EMCalcBornCharges"))
insDoc(aux2, gLnk("R", "EMCalcMagnetooptics", "vars/Linear_Response.html#EMCalcMagnetooptics"))
insDoc(aux2, gLnk("R", "EMCalcRotatoryResponse", "vars/Linear_Response.html#EMCalcRotatoryResponse"))
insDoc(aux2, gLnk("R", "EMEta", "vars/Linear_Response.html#EMEta"))
insDoc(aux2, gLnk("R", "EMForceNoKdotP", "vars/Linear_Response.html#EMForceNoKdotP"))
insDoc(aux2, gLnk("R", "EMFreqs", "vars/Linear_Response.html#EMFreqs"))
insDoc(aux2, gLnk("R", "EMFreqsSort", "vars/Linear_Response.html#EMFreqsSort"))
insDoc(aux2, gLnk("R", "EMHyperpol", "vars/Linear_Response.html#EMHyperpol"))
insDoc(aux2, gLnk("R", "EMMagnetoopticsNoHVar", "vars/Linear_Response.html#EMMagnetoopticsNoHVar"))
insDoc(aux2, gLnk("R", "EMOccupiedResponse", "vars/Linear_Response.html#EMOccupiedResponse"))
insDoc(aux2, gLnk("R", "EMPerturbationType", "vars/Linear_Response.html#EMPerturbationType"))
insDoc(aux2, gLnk("R", "EMWavefunctionsFromScratch", "vars/Linear_Response.html#EMWavefunctionsFromScratch"))
insDoc(aux2, gLnk("R", "vdWNPoints", "vars/Linear_Response.html#vdWNPoints"))
aux2 = insFld(aux1, gFld("SCF in LR calculations", "vars/Linear_Response.html#Linear_Response::SCF_in_LR_calculations"))
insDoc(aux2, gLnk("R", "LRConvAbsDens", "vars/Linear_Response.html#LRConvAbsDens"))
insDoc(aux2, gLnk("R", "LRConvRelDens", "vars/Linear_Response.html#LRConvRelDens"))
insDoc(aux2, gLnk("R", "LRMaximumIter", "vars/Linear_Response.html#LRMaximumIter"))
insDoc(aux2, gLnk("R", "LRTolAdaptiveFactor", "vars/Linear_Response.html#LRTolAdaptiveFactor"))
insDoc(aux2, gLnk("R", "LRTolIterWindow", "vars/Linear_Response.html#LRTolIterWindow"))
insDoc(aux2, gLnk("R", "LRTolScheme", "vars/Linear_Response.html#LRTolScheme"))
aux2 = insFld(aux1, gFld("Solver", "vars/Linear_Response.html#Linear_Response::Solver"))
insDoc(aux2, gLnk("R", "LRTolFinalTol", "vars/Linear_Response.html#LRTolFinalTol"))
insDoc(aux2, gLnk("R", "LRTolInitTol", "vars/Linear_Response.html#LRTolInitTol"))
insDoc(aux2, gLnk("R", "LinearSolver", "vars/Linear_Response.html#LinearSolver"))
insDoc(aux2, gLnk("R", "LinearSolverMaxIter", "vars/Linear_Response.html#LinearSolverMaxIter"))
aux2 = insFld(aux1, gFld("Static Polarization", "vars/Linear_Response.html#Linear_Response::Static_Polarization"))
insDoc(aux2, gLnk("R", "EMCalcDiagonalField", "vars/Linear_Response.html#EMCalcDiagonalField"))
insDoc(aux2, gLnk("R", "EMStartDensityIsZeroField", "vars/Linear_Response.html#EMStartDensityIsZeroField"))
insDoc(aux2, gLnk("R", "EMStaticElectricField", "vars/Linear_Response.html#EMStaticElectricField"))
insDoc(aux2, gLnk("R", "EMVerbose", "vars/Linear_Response.html#EMVerbose"))
insDoc(aux2, gLnk("R", "EMWriteRestartDensities", "vars/Linear_Response.html#EMWriteRestartDensities"))
aux2 = insFld(aux1, gFld("Sternheimer", "vars/Linear_Response.html#Linear_Response::Sternheimer"))
insDoc(aux2, gLnk("R", "HamiltonianVariation", "vars/Linear_Response.html#HamiltonianVariation"))
insDoc(aux2, gLnk("R", "Preorthogonalization", "vars/Linear_Response.html#Preorthogonalization"))
aux2 = insFld(aux1, gFld("Vibrational Modes", "vars/Linear_Response.html#Linear_Response::Vibrational_Modes"))
insDoc(aux2, gLnk("R", "CalcInfrared", "vars/Linear_Response.html#CalcInfrared"))
insDoc(aux2, gLnk("R", "CalcNormalModeWfs", "vars/Linear_Response.html#CalcNormalModeWfs"))
insDoc(aux2, gLnk("R", "Displacement", "vars/Linear_Response.html#Displacement"))
insDoc(aux2, gLnk("R", "SymmetrizeDynamicalMatrix", "vars/Linear_Response.html#SymmetrizeDynamicalMatrix"))
aux1 = insFld(aux0, gFld("Math", "vars/Math.html#Math::RootSolver"))
aux2 = insFld(aux1, gFld("RootSolver", "vars/Math.html#Math::RootSolver"))
insDoc(aux2, gLnk("R", "RootSolver", "vars/Math.html#RootSolver"))
insDoc(aux2, gLnk("R", "RootSolverAbsTolerance", "vars/Math.html#RootSolverAbsTolerance"))
insDoc(aux2, gLnk("R", "RootSolverHavePolynomial", "vars/Math.html#RootSolverHavePolynomial"))
insDoc(aux2, gLnk("R", "RootSolverMaxIter", "vars/Math.html#RootSolverMaxIter"))
insDoc(aux2, gLnk("R", "RootSolverRelTolerance", "vars/Math.html#RootSolverRelTolerance"))
insDoc(aux2, gLnk("R", "RootSolverWSRadius", "vars/Math.html#RootSolverWSRadius"))
insDoc(aux2, gLnk("R", "WatterstromODESolver", "vars/Math.html#WatterstromODESolver"))
insDoc(aux2, gLnk("R", "WatterstromODESolverNSteps", "vars/Math.html#WatterstromODESolverNSteps"))
aux2 = insFld(aux1, gFld("SPARSKIT", "vars/Math.html#Math::SPARSKIT"))
insDoc(aux2, gLnk("R", "SPARSKITAbsTolerance", "vars/Math.html#SPARSKITAbsTolerance"))
insDoc(aux2, gLnk("R", "SPARSKITIterOut", "vars/Math.html#SPARSKITIterOut"))
insDoc(aux2, gLnk("R", "SPARSKITKrylovSubspaceSize", "vars/Math.html#SPARSKITKrylovSubspaceSize"))
insDoc(aux2, gLnk("R", "SPARSKITMaxIter", "vars/Math.html#SPARSKITMaxIter"))
insDoc(aux2, gLnk("R", "SPARSKITRelTolerance", "vars/Math.html#SPARSKITRelTolerance"))
insDoc(aux2, gLnk("R", "SPARSKITSolver", "vars/Math.html#SPARSKITSolver"))
insDoc(aux2, gLnk("R", "SPARSKITVerboseSolver", "vars/Math.html#SPARSKITVerboseSolver"))
aux1 = insFld(aux0, gFld("Mesh", "vars/Mesh.html#Mesh"))
insDoc(aux1, gLnk("R", "DoubleGrid", "vars/Mesh.html#DoubleGrid"))
insDoc(aux1, gLnk("R", "DoubleGridOrder", "vars/Mesh.html#DoubleGridOrder"))
insDoc(aux1, gLnk("R", "MultiResolutionArea", "vars/Mesh.html#MultiResolutionArea"))
insDoc(aux1, gLnk("R", "MultiResolutionInterpolationOrder", "vars/Mesh.html#MultiResolutionInterpolationOrder"))
insDoc(aux1, gLnk("R", "MultigridLevels", "vars/Mesh.html#MultigridLevels"))
insDoc(aux1, gLnk("R", "Spacing", "vars/Mesh.html#Spacing"))
insDoc(aux1, gLnk("R", "UseFineMesh", "vars/Mesh.html#UseFineMesh"))
aux2 = insFld(aux1, gFld("Curvilinear", "vars/Mesh.html#Mesh::Curvilinear"))
insDoc(aux2, gLnk("R", "CurvMethod", "vars/Mesh.html#CurvMethod"))
aux3 = insFld(aux2, gFld("Gygi", "vars/Mesh.html#Mesh::Curvilinear::Gygi"))
insDoc(aux3, gLnk("R", "CurvGygiA", "vars/Mesh.html#CurvGygiA"))
insDoc(aux3, gLnk("R", "CurvGygiAlpha", "vars/Mesh.html#CurvGygiAlpha"))
insDoc(aux3, gLnk("R", "CurvGygiBeta", "vars/Mesh.html#CurvGygiBeta"))
aux3 = insFld(aux2, gFld("Modine", "vars/Mesh.html#Mesh::Curvilinear::Modine"))
insDoc(aux3, gLnk("R", "CurvModineJBar", "vars/Mesh.html#CurvModineJBar"))
insDoc(aux3, gLnk("R", "CurvModineJlocal", "vars/Mesh.html#CurvModineJlocal"))
insDoc(aux3, gLnk("R", "CurvModineJrange", "vars/Mesh.html#CurvModineJrange"))
insDoc(aux3, gLnk("R", "CurvModineXBar", "vars/Mesh.html#CurvModineXBar"))
aux2 = insFld(aux1, gFld("Derivatives", "vars/Mesh.html#Mesh::Derivatives"))
insDoc(aux2, gLnk("R", "DerivativesOrder", "vars/Mesh.html#DerivativesOrder"))
insDoc(aux2, gLnk("R", "DerivativesStencil", "vars/Mesh.html#DerivativesStencil"))
aux2 = insFld(aux1, gFld("FFTs", "vars/Mesh.html#Mesh::FFTs"))
insDoc(aux2, gLnk("R", "DoubleFFTParameter", "vars/Mesh.html#DoubleFFTParameter"))
insDoc(aux2, gLnk("R", "FFTLibrary", "vars/Mesh.html#FFTLibrary"))
insDoc(aux2, gLnk("R", "FFTOptimize", "vars/Mesh.html#FFTOptimize"))
insDoc(aux2, gLnk("R", "FFTPreparePlan", "vars/Mesh.html#FFTPreparePlan"))
insDoc(aux2, gLnk("R", "NFFTCutoff", "vars/Mesh.html#NFFTCutoff"))
insDoc(aux2, gLnk("R", "NFFTGuruInterface", "vars/Mesh.html#NFFTGuruInterface"))
insDoc(aux2, gLnk("R", "NFFTOversampling", "vars/Mesh.html#NFFTOversampling"))
insDoc(aux2, gLnk("R", "NFFTPrecompute", "vars/Mesh.html#NFFTPrecompute"))
insDoc(aux2, gLnk("R", "PNFFTCutoff", "vars/Mesh.html#PNFFTCutoff"))
insDoc(aux2, gLnk("R", "PNFFTOversampling", "vars/Mesh.html#PNFFTOversampling"))
aux2 = insFld(aux1, gFld("KPoints", "vars/Mesh.html#Mesh::KPoints"))
insDoc(aux2, gLnk("R", "KPoints", "vars/Mesh.html#KPoints"))
insDoc(aux2, gLnk("R", "KPointsGrid", "vars/Mesh.html#KPointsGrid"))
insDoc(aux2, gLnk("R", "KPointsPath", "vars/Mesh.html#KPointsPath"))
insDoc(aux2, gLnk("R", "KPointsReduced", "vars/Mesh.html#KPointsReduced"))
insDoc(aux2, gLnk("R", "KPointsUseSymmetries", "vars/Mesh.html#KPointsUseSymmetries"))
insDoc(aux2, gLnk("R", "KPointsUseTimeReversal", "vars/Mesh.html#KPointsUseTimeReversal"))
aux2 = insFld(aux1, gFld("Simulation Box", "vars/Mesh.html#Mesh::Simulation_Box"))
insDoc(aux2, gLnk("R", "BoxShape", "vars/Mesh.html#BoxShape"))
insDoc(aux2, gLnk("R", "BoxShapeImage", "vars/Mesh.html#BoxShapeImage"))
insDoc(aux2, gLnk("R", "BoxShapeUsDef", "vars/Mesh.html#BoxShapeUsDef"))
insDoc(aux2, gLnk("R", "LatticeParameters", "vars/Mesh.html#LatticeParameters"))
insDoc(aux2, gLnk("R", "LatticeVectors", "vars/Mesh.html#LatticeVectors"))
insDoc(aux2, gLnk("R", "Lsize", "vars/Mesh.html#Lsize"))
insDoc(aux2, gLnk("R", "Radius", "vars/Mesh.html#Radius"))
insDoc(aux2, gLnk("R", "SymmetryBreakDir", "vars/Mesh.html#SymmetryBreakDir"))
insDoc(aux2, gLnk("R", "Xlength", "vars/Mesh.html#Xlength"))
aux1 = insFld(aux0, gFld("Output", "vars/Output.html#Output"))
insDoc(aux1, gLnk("R", "CurrentThroughPlane", "vars/Output.html#CurrentThroughPlane"))
insDoc(aux1, gLnk("R", "DOSEnergyMax", "vars/Output.html#DOSEnergyMax"))
insDoc(aux1, gLnk("R", "DOSEnergyMin", "vars/Output.html#DOSEnergyMin"))
insDoc(aux1, gLnk("R", "DOSEnergyPoints", "vars/Output.html#DOSEnergyPoints"))
insDoc(aux1, gLnk("R", "DOSGamma", "vars/Output.html#DOSGamma"))
insDoc(aux1, gLnk("R", "ELFWithCurrentTerm", "vars/Output.html#ELFWithCurrentTerm"))
insDoc(aux1, gLnk("R", "LocalMagneticMomentsSphereRadius", "vars/Output.html#LocalMagneticMomentsSphereRadius"))
insDoc(aux1, gLnk("R", "MomentumTransfer", "vars/Output.html#MomentumTransfer"))
insDoc(aux1, gLnk("R", "OpenSCADIsovalue", "vars/Output.html#OpenSCADIsovalue"))
insDoc(aux1, gLnk("R", "Output", "vars/Output.html#Output"))
insDoc(aux1, gLnk("R", "OutputBandsGnuplotMode", "vars/Output.html#OutputBandsGnuplotMode"))
insDoc(aux1, gLnk("R", "OutputBandsGraceMode", "vars/Output.html#OutputBandsGraceMode"))
insDoc(aux1, gLnk("R", "OutputDuringSCF", "vars/Output.html#OutputDuringSCF"))
insDoc(aux1, gLnk("R", "OutputFormat", "vars/Output.html#OutputFormat"))
insDoc(aux1, gLnk("R", "OutputInterval", "vars/Output.html#OutputInterval"))
insDoc(aux1, gLnk("R", "OutputIterDir", "vars/Output.html#OutputIterDir"))
insDoc(aux1, gLnk("R", "OutputMEMultipoles", "vars/Output.html#OutputMEMultipoles"))
insDoc(aux1, gLnk("R", "OutputMatrixElements", "vars/Output.html#OutputMatrixElements"))
insDoc(aux1, gLnk("R", "OutputWfsNumber", "vars/Output.html#OutputWfsNumber"))
aux2 = insFld(aux1, gFld("BerkeleyGW", "vars/Output.html#Output::BerkeleyGW"))
insDoc(aux2, gLnk("R", "BerkeleyGW_CalcDipoleMtxels", "vars/Output.html#BerkeleyGW_CalcDipoleMtxels"))
insDoc(aux2, gLnk("R", "BerkeleyGW_CalcExchange", "vars/Output.html#BerkeleyGW_CalcExchange"))
insDoc(aux2, gLnk("R", "BerkeleyGW_NumberBands", "vars/Output.html#BerkeleyGW_NumberBands"))
insDoc(aux2, gLnk("R", "BerkeleyGW_VmtxelNumCondBands", "vars/Output.html#BerkeleyGW_VmtxelNumCondBands"))
insDoc(aux2, gLnk("R", "BerkeleyGW_VmtxelNumValBands", "vars/Output.html#BerkeleyGW_VmtxelNumValBands"))
insDoc(aux2, gLnk("R", "BerkeleyGW_VmtxelPolarization", "vars/Output.html#BerkeleyGW_VmtxelPolarization"))
insDoc(aux2, gLnk("R", "BerkeleyGW_Vxc_diag_nmax", "vars/Output.html#BerkeleyGW_Vxc_diag_nmax"))
insDoc(aux2, gLnk("R", "BerkeleyGW_Vxc_diag_nmin", "vars/Output.html#BerkeleyGW_Vxc_diag_nmin"))
insDoc(aux2, gLnk("R", "BerkeleyGW_Vxc_offdiag_nmax", "vars/Output.html#BerkeleyGW_Vxc_offdiag_nmax"))
insDoc(aux2, gLnk("R", "BerkeleyGW_Vxc_offdiag_nmin", "vars/Output.html#BerkeleyGW_Vxc_offdiag_nmin"))
insDoc(aux2, gLnk("R", "BerkeleyGW_WFN_filename", "vars/Output.html#BerkeleyGW_WFN_filename"))
aux2 = insFld(aux1, gFld("Subsystems", "vars/Output.html#Output::Subsystems"))
insDoc(aux2, gLnk("R", "FrozenDir", "vars/Output.html#FrozenDir"))
insDoc(aux2, gLnk("R", "FrozenStates", "vars/Output.html#FrozenStates"))
aux1 = insFld(aux0, gFld("SCF", "vars/SCF.html#SCF"))
insDoc(aux1, gLnk("R", "CalcEigenvalues", "vars/SCF.html#CalcEigenvalues"))
insDoc(aux1, gLnk("R", "SCFCalculateDipole", "vars/SCF.html#SCFCalculateDipole"))
insDoc(aux1, gLnk("R", "SCFCalculateForces", "vars/SCF.html#SCFCalculateForces"))
insDoc(aux1, gLnk("R", "SCFCalculatePartialCharges", "vars/SCF.html#SCFCalculatePartialCharges"))
insDoc(aux1, gLnk("R", "SCFCalculateStress", "vars/SCF.html#SCFCalculateStress"))
insDoc(aux1, gLnk("R", "SCFinLCAO", "vars/SCF.html#SCFinLCAO"))
aux2 = insFld(aux1, gFld("Convergence", "vars/SCF.html#SCF::Convergence"))
insDoc(aux2, gLnk("R", "ConvAbsDens", "vars/SCF.html#ConvAbsDens"))
insDoc(aux2, gLnk("R", "ConvAbsEv", "vars/SCF.html#ConvAbsEv"))
insDoc(aux2, gLnk("R", "ConvEigenError", "vars/SCF.html#ConvEigenError"))
insDoc(aux2, gLnk("R", "ConvEnergy", "vars/SCF.html#ConvEnergy"))
insDoc(aux2, gLnk("R", "ConvForce", "vars/SCF.html#ConvForce"))
insDoc(aux2, gLnk("R", "ConvRelDens", "vars/SCF.html#ConvRelDens"))
insDoc(aux2, gLnk("R", "ConvRelEv", "vars/SCF.html#ConvRelEv"))
insDoc(aux2, gLnk("R", "MaximumIter", "vars/SCF.html#MaximumIter"))
insDoc(aux2, gLnk("R", "MaximumIterBerry", "vars/SCF.html#MaximumIterBerry"))
aux2 = insFld(aux1, gFld("Eigensolver", "vars/SCF.html#SCF::Eigensolver"))
insDoc(aux2, gLnk("R", "Eigensolver", "vars/SCF.html#Eigensolver"))
insDoc(aux2, gLnk("R", "EigensolverArnoldiVectors", "vars/SCF.html#EigensolverArnoldiVectors"))
insDoc(aux2, gLnk("R", "EigensolverImaginaryTime", "vars/SCF.html#EigensolverImaginaryTime"))
insDoc(aux2, gLnk("R", "EigensolverMaxIter", "vars/SCF.html#EigensolverMaxIter"))
insDoc(aux2, gLnk("R", "EigensolverMinimizationIter", "vars/SCF.html#EigensolverMinimizationIter"))
insDoc(aux2, gLnk("R", "EigensolverSaveMemory", "vars/SCF.html#EigensolverSaveMemory"))
insDoc(aux2, gLnk("R", "EigensolverTolerance", "vars/SCF.html#EigensolverTolerance"))
insDoc(aux2, gLnk("R", "Preconditioner", "vars/SCF.html#Preconditioner"))
insDoc(aux2, gLnk("R", "PreconditionerFilterFactor", "vars/SCF.html#PreconditionerFilterFactor"))
insDoc(aux2, gLnk("R", "StatesOrthogonalization", "vars/SCF.html#StatesOrthogonalization"))
insDoc(aux2, gLnk("R", "SubspaceDiagonalization", "vars/SCF.html#SubspaceDiagonalization"))
aux3 = insFld(aux2, gFld("ARPACK", "vars/SCF.html#SCF::Eigensolver::ARPACK"))
insDoc(aux3, gLnk("R", "ArpackInitialTolerance", "vars/SCF.html#ArpackInitialTolerance"))
insDoc(aux3, gLnk("R", "EigensolverArpackInitialResid", "vars/SCF.html#EigensolverArpackInitialResid"))
insDoc(aux3, gLnk("R", "EigensolverArpackSort", "vars/SCF.html#EigensolverArpackSort"))
insDoc(aux3, gLnk("R", "EigensolverParpack", "vars/SCF.html#EigensolverParpack"))
aux3 = insFld(aux2, gFld("FEAST", "vars/SCF.html#SCF::Eigensolver::FEAST"))
insDoc(aux3, gLnk("R", "FeastContour", "vars/SCF.html#FeastContour"))
insDoc(aux3, gLnk("R", "FeastMaxIter", "vars/SCF.html#FeastMaxIter"))
aux2 = insFld(aux1, gFld("LCAO", "vars/SCF.html#SCF::LCAO"))
insDoc(aux2, gLnk("R", "AtomsMagnetDirection", "vars/SCF.html#AtomsMagnetDirection"))
insDoc(aux2, gLnk("R", "GuessMagnetDensity", "vars/SCF.html#GuessMagnetDensity"))
insDoc(aux2, gLnk("R", "LCAOAlternative", "vars/SCF.html#LCAOAlternative"))
insDoc(aux2, gLnk("R", "LCAOComplexYlms", "vars/SCF.html#LCAOComplexYlms"))
insDoc(aux2, gLnk("R", "LCAODiagTol", "vars/SCF.html#LCAODiagTol"))
insDoc(aux2, gLnk("R", "LCAODimension", "vars/SCF.html#LCAODimension"))
insDoc(aux2, gLnk("R", "LCAOExtraOrbitals", "vars/SCF.html#LCAOExtraOrbitals"))
insDoc(aux2, gLnk("R", "LCAOKeepOrbitals", "vars/SCF.html#LCAOKeepOrbitals"))
insDoc(aux2, gLnk("R", "LCAOMaximumOrbitalRadius", "vars/SCF.html#LCAOMaximumOrbitalRadius"))
insDoc(aux2, gLnk("R", "LCAOScaleFactor", "vars/SCF.html#LCAOScaleFactor"))
insDoc(aux2, gLnk("R", "LCAOStart", "vars/SCF.html#LCAOStart"))
aux2 = insFld(aux1, gFld("Mixing", "vars/SCF.html#SCF::Mixing"))
insDoc(aux2, gLnk("R", "MixField", "vars/SCF.html#MixField"))
insDoc(aux2, gLnk("R", "MixInterval", "vars/SCF.html#MixInterval"))
insDoc(aux2, gLnk("R", "MixNumberSteps", "vars/SCF.html#MixNumberSteps"))
insDoc(aux2, gLnk("R", "Mixing", "vars/SCF.html#Mixing"))
insDoc(aux2, gLnk("R", "MixingPreconditioner", "vars/SCF.html#MixingPreconditioner"))
insDoc(aux2, gLnk("R", "MixingResidual", "vars/SCF.html#MixingResidual"))
insDoc(aux2, gLnk("R", "MixingScheme", "vars/SCF.html#MixingScheme"))
aux2 = insFld(aux1, gFld("RDMFT", "vars/SCF.html#SCF::RDMFT"))
insDoc(aux2, gLnk("R", "RDMBasis", "vars/SCF.html#RDMBasis"))
insDoc(aux2, gLnk("R", "RDMConvEner", "vars/SCF.html#RDMConvEner"))
insDoc(aux2, gLnk("R", "RDMTolerance", "vars/SCF.html#RDMTolerance"))
aux1 = insFld(aux0, gFld("States", "vars/States.html#States"))
insDoc(aux1, gLnk("R", "DegeneracyThreshold", "vars/States.html#DegeneracyThreshold"))
insDoc(aux1, gLnk("R", "ExcessCharge", "vars/States.html#ExcessCharge"))
insDoc(aux1, gLnk("R", "ExtraStates", "vars/States.html#ExtraStates"))
insDoc(aux1, gLnk("R", "InitialSpins", "vars/States.html#InitialSpins"))
insDoc(aux1, gLnk("R", "Occupations", "vars/States.html#Occupations"))
insDoc(aux1, gLnk("R", "OnlyUserDefinedInitialStates", "vars/States.html#OnlyUserDefinedInitialStates"))
insDoc(aux1, gLnk("R", "RestartFixedOccupations", "vars/States.html#RestartFixedOccupations"))
insDoc(aux1, gLnk("R", "RestartReorderOccs", "vars/States.html#RestartReorderOccs"))
insDoc(aux1, gLnk("R", "Smearing", "vars/States.html#Smearing"))
insDoc(aux1, gLnk("R", "SmearingFunction", "vars/States.html#SmearingFunction"))
insDoc(aux1, gLnk("R", "SmearingMPOrder", "vars/States.html#SmearingMPOrder"))
insDoc(aux1, gLnk("R", "SpinComponents", "vars/States.html#SpinComponents"))
insDoc(aux1, gLnk("R", "StatesRandomization", "vars/States.html#StatesRandomization"))
insDoc(aux1, gLnk("R", "SymmetrizeDensity", "vars/States.html#SymmetrizeDensity"))
insDoc(aux1, gLnk("R", "TotalStates", "vars/States.html#TotalStates"))
insDoc(aux1, gLnk("R", "TransformStates", "vars/States.html#TransformStates"))
insDoc(aux1, gLnk("R", "UserDefinedStates", "vars/States.html#UserDefinedStates"))
aux2 = insFld(aux1, gFld("ModelMB", "vars/States.html#States::ModelMB"))
insDoc(aux2, gLnk("R", "DensitytoCalc", "vars/States.html#DensitytoCalc"))
insDoc(aux2, gLnk("R", "DescribeParticlesModelmb", "vars/States.html#DescribeParticlesModelmb"))
insDoc(aux2, gLnk("R", "NDimModelmb", "vars/States.html#NDimModelmb"))
insDoc(aux2, gLnk("R", "NParticleModelmb", "vars/States.html#NParticleModelmb"))
insDoc(aux2, gLnk("R", "NTypeParticleModelmb", "vars/States.html#NTypeParticleModelmb"))
aux1 = insFld(aux0, gFld("System", "vars/System.html#System"))
insDoc(aux1, gLnk("R", "Dimensions", "vars/System.html#Dimensions"))
insDoc(aux1, gLnk("R", "PeriodicDimensions", "vars/System.html#PeriodicDimensions"))
aux2 = insFld(aux1, gFld("Coordinates", "vars/System.html#System::Coordinates"))
insDoc(aux2, gLnk("R", "Coordinates", "vars/System.html#Coordinates"))
insDoc(aux2, gLnk("R", "PDBClassical", "vars/System.html#PDBClassical"))
insDoc(aux2, gLnk("R", "PDBCoordinates", "vars/System.html#PDBCoordinates"))
insDoc(aux2, gLnk("R", "ReducedCoordinates", "vars/System.html#ReducedCoordinates"))
insDoc(aux2, gLnk("R", "XSFCoordinates", "vars/System.html#XSFCoordinates"))
insDoc(aux2, gLnk("R", "XSFCoordinatesAnimStep", "vars/System.html#XSFCoordinatesAnimStep"))
insDoc(aux2, gLnk("R", "XYZCoordinates", "vars/System.html#XYZCoordinates"))
aux2 = insFld(aux1, gFld("Species", "vars/System.html#System::Species"))
insDoc(aux2, gLnk("R", "IonicInteraction", "vars/System.html#IonicInteraction"))
insDoc(aux2, gLnk("R", "PseudopotentialSet", "vars/System.html#PseudopotentialSet"))
insDoc(aux2, gLnk("R", "Species", "vars/System.html#Species"))
insDoc(aux2, gLnk("R", "SpeciesProjectorSphereThreshold", "vars/System.html#SpeciesProjectorSphereThreshold"))
insDoc(aux2, gLnk("R", "SpeciesTimeDependent", "vars/System.html#SpeciesTimeDependent"))
aux2 = insFld(aux1, gFld("Subsystems", "vars/System.html#System::Subsystems"))
insDoc(aux2, gLnk("R", "SubSystemCoordinates", "vars/System.html#SubSystemCoordinates"))
insDoc(aux2, gLnk("R", "SubSystems", "vars/System.html#SubSystems"))
aux2 = insFld(aux1, gFld("Velocities", "vars/System.html#System::Velocities"))
insDoc(aux2, gLnk("R", "PDBVelocities", "vars/System.html#PDBVelocities"))
insDoc(aux2, gLnk("R", "RandomVelocityTemp", "vars/System.html#RandomVelocityTemp"))
insDoc(aux2, gLnk("R", "Velocities", "vars/System.html#Velocities"))
insDoc(aux2, gLnk("R", "XSFVelocities", "vars/System.html#XSFVelocities"))
insDoc(aux2, gLnk("R", "XYZVelocities", "vars/System.html#XYZVelocities"))
aux1 = insFld(aux0, gFld("Time-Dependent", "vars/Time-Dependent.html#Time-Dependent"))
insDoc(aux1, gLnk("R", "TDExternalFields", "vars/Time-Dependent.html#TDExternalFields"))
insDoc(aux1, gLnk("R", "TDFreezeHXC", "vars/Time-Dependent.html#TDFreezeHXC"))
insDoc(aux1, gLnk("R", "TDFreezeOrbitals", "vars/Time-Dependent.html#TDFreezeOrbitals"))
insDoc(aux1, gLnk("R", "TDFunctions", "vars/Time-Dependent.html#TDFunctions"))
insDoc(aux1, gLnk("R", "TDGlobalForce", "vars/Time-Dependent.html#TDGlobalForce"))
insDoc(aux1, gLnk("R", "TDScissor", "vars/Time-Dependent.html#TDScissor"))
aux2 = insFld(aux1, gFld("Absorbing Boundaries", "vars/Time-Dependent.html#Time-Dependent::Absorbing_Boundaries"))
insDoc(aux2, gLnk("R", "ABCapHeight", "vars/Time-Dependent.html#ABCapHeight"))
insDoc(aux2, gLnk("R", "ABShape", "vars/Time-Dependent.html#ABShape"))
insDoc(aux2, gLnk("R", "ABWidth", "vars/Time-Dependent.html#ABWidth"))
insDoc(aux2, gLnk("R", "AbsorbingBoundaries", "vars/Time-Dependent.html#AbsorbingBoundaries"))
aux2 = insFld(aux1, gFld("PhotoElectronSpectrum", "vars/Time-Dependent.html#Time-Dependent::PhotoElectronSpectrum"))
insDoc(aux2, gLnk("R", "PESMask2PEnlargeFactor", "vars/Time-Dependent.html#PESMask2PEnlargeFactor"))
insDoc(aux2, gLnk("R", "PESMaskEnlargeFactor", "vars/Time-Dependent.html#PESMaskEnlargeFactor"))
insDoc(aux2, gLnk("R", "PESMaskFilterCutOff", "vars/Time-Dependent.html#PESMaskFilterCutOff"))
insDoc(aux2, gLnk("R", "PESMaskIncludePsiA", "vars/Time-Dependent.html#PESMaskIncludePsiA"))
insDoc(aux2, gLnk("R", "PESMaskMode", "vars/Time-Dependent.html#PESMaskMode"))
insDoc(aux2, gLnk("R", "PESMaskPlaneWaveProjection", "vars/Time-Dependent.html#PESMaskPlaneWaveProjection"))
insDoc(aux2, gLnk("R", "PESMaskShape", "vars/Time-Dependent.html#PESMaskShape"))
insDoc(aux2, gLnk("R", "PESMaskSize", "vars/Time-Dependent.html#PESMaskSize"))
insDoc(aux2, gLnk("R", "PESMaskSpectEnergyMax", "vars/Time-Dependent.html#PESMaskSpectEnergyMax"))
insDoc(aux2, gLnk("R", "PESMaskSpectEnergyStep", "vars/Time-Dependent.html#PESMaskSpectEnergyStep"))
insDoc(aux2, gLnk("R", "PESMaskStartTime", "vars/Time-Dependent.html#PESMaskStartTime"))
insDoc(aux2, gLnk("R", "PES_Flux_ARPES_grid", "vars/Time-Dependent.html#PES_Flux_ARPES_grid"))
insDoc(aux2, gLnk("R", "PES_Flux_AvoidAB", "vars/Time-Dependent.html#PES_Flux_AvoidAB"))
insDoc(aux2, gLnk("R", "PES_Flux_BZones", "vars/Time-Dependent.html#PES_Flux_BZones"))
insDoc(aux2, gLnk("R", "PES_Flux_DeltaK", "vars/Time-Dependent.html#PES_Flux_DeltaK"))
insDoc(aux2, gLnk("R", "PES_Flux_EnergyGrid", "vars/Time-Dependent.html#PES_Flux_EnergyGrid"))
insDoc(aux2, gLnk("R", "PES_Flux_Gpoint_Upsample", "vars/Time-Dependent.html#PES_Flux_Gpoint_Upsample"))
insDoc(aux2, gLnk("R", "PES_Flux_Kmax", "vars/Time-Dependent.html#PES_Flux_Kmax"))
insDoc(aux2, gLnk("R", "PES_Flux_Lmax", "vars/Time-Dependent.html#PES_Flux_Lmax"))
insDoc(aux2, gLnk("R", "PES_Flux_Lsize", "vars/Time-Dependent.html#PES_Flux_Lsize"))
insDoc(aux2, gLnk("R", "PES_Flux_Offset", "vars/Time-Dependent.html#PES_Flux_Offset"))
insDoc(aux2, gLnk("R", "PES_Flux_Radius", "vars/Time-Dependent.html#PES_Flux_Radius"))
insDoc(aux2, gLnk("R", "PES_Flux_Shape", "vars/Time-Dependent.html#PES_Flux_Shape"))
insDoc(aux2, gLnk("R", "PES_Flux_StepsPhiK", "vars/Time-Dependent.html#PES_Flux_StepsPhiK"))
insDoc(aux2, gLnk("R", "PES_Flux_StepsPhiR", "vars/Time-Dependent.html#PES_Flux_StepsPhiR"))
insDoc(aux2, gLnk("R", "PES_Flux_StepsThetaK", "vars/Time-Dependent.html#PES_Flux_StepsThetaK"))
insDoc(aux2, gLnk("R", "PES_Flux_StepsThetaR", "vars/Time-Dependent.html#PES_Flux_StepsThetaR"))
insDoc(aux2, gLnk("R", "PES_Flux_UseMemory", "vars/Time-Dependent.html#PES_Flux_UseMemory"))
insDoc(aux2, gLnk("R", "PES_spm_DeltaOmega", "vars/Time-Dependent.html#PES_spm_DeltaOmega"))
insDoc(aux2, gLnk("R", "PES_spm_OmegaMax", "vars/Time-Dependent.html#PES_spm_OmegaMax"))
insDoc(aux2, gLnk("R", "PES_spm_Radius", "vars/Time-Dependent.html#PES_spm_Radius"))
insDoc(aux2, gLnk("R", "PES_spm_StepsPhiR", "vars/Time-Dependent.html#PES_spm_StepsPhiR"))
insDoc(aux2, gLnk("R", "PES_spm_StepsThetaR", "vars/Time-Dependent.html#PES_spm_StepsThetaR"))
insDoc(aux2, gLnk("R", "PES_spm_points", "vars/Time-Dependent.html#PES_spm_points"))
insDoc(aux2, gLnk("R", "PES_spm_recipe", "vars/Time-Dependent.html#PES_spm_recipe"))
insDoc(aux2, gLnk("R", "PhotoElectronSpectrum", "vars/Time-Dependent.html#PhotoElectronSpectrum"))
aux2 = insFld(aux1, gFld("Propagation", "vars/Time-Dependent.html#Time-Dependent::Propagation"))
insDoc(aux2, gLnk("R", "IonsConstantVelocity", "vars/Time-Dependent.html#IonsConstantVelocity"))
insDoc(aux2, gLnk("R", "IonsTimeDependentDisplacements", "vars/Time-Dependent.html#IonsTimeDependentDisplacements"))
insDoc(aux2, gLnk("R", "MoveIons", "vars/Time-Dependent.html#MoveIons"))
insDoc(aux2, gLnk("R", "RecalculateGSDuringEvolution", "vars/Time-Dependent.html#RecalculateGSDuringEvolution"))
insDoc(aux2, gLnk("R", "TDDynamics", "vars/Time-Dependent.html#TDDynamics"))
insDoc(aux2, gLnk("R", "TDEnergyUpdateIter", "vars/Time-Dependent.html#TDEnergyUpdateIter"))
insDoc(aux2, gLnk("R", "TDExpOrder", "vars/Time-Dependent.html#TDExpOrder"))
insDoc(aux2, gLnk("R", "TDExponentialMethod", "vars/Time-Dependent.html#TDExponentialMethod"))
insDoc(aux2, gLnk("R", "TDIonicTimeScale", "vars/Time-Dependent.html#TDIonicTimeScale"))
insDoc(aux2, gLnk("R", "TDLanczosTol", "vars/Time-Dependent.html#TDLanczosTol"))
insDoc(aux2, gLnk("R", "TDMaxSteps", "vars/Time-Dependent.html#TDMaxSteps"))
insDoc(aux2, gLnk("R", "TDPropagationTime", "vars/Time-Dependent.html#TDPropagationTime"))
insDoc(aux2, gLnk("R", "TDPropagator", "vars/Time-Dependent.html#TDPropagator"))
insDoc(aux2, gLnk("R", "TDSCFThreshold", "vars/Time-Dependent.html#TDSCFThreshold"))
insDoc(aux2, gLnk("R", "TDStepsWithSelfConsistency", "vars/Time-Dependent.html#TDStepsWithSelfConsistency"))
insDoc(aux2, gLnk("R", "TDTimeStep", "vars/Time-Dependent.html#TDTimeStep"))
insDoc(aux2, gLnk("R", "TemperatureFunction", "vars/Time-Dependent.html#TemperatureFunction"))
insDoc(aux2, gLnk("R", "Thermostat", "vars/Time-Dependent.html#Thermostat"))
insDoc(aux2, gLnk("R", "ThermostatMass", "vars/Time-Dependent.html#ThermostatMass"))
aux2 = insFld(aux1, gFld("Response", "vars/Time-Dependent.html#Time-Dependent::Response"))
insDoc(aux2, gLnk("R", "TDDeltaKickTime", "vars/Time-Dependent.html#TDDeltaKickTime"))
insDoc(aux2, gLnk("R", "TDDeltaStrength", "vars/Time-Dependent.html#TDDeltaStrength"))
insDoc(aux2, gLnk("R", "TDDeltaStrengthMode", "vars/Time-Dependent.html#TDDeltaStrengthMode"))
insDoc(aux2, gLnk("R", "TDDeltaUserDefined", "vars/Time-Dependent.html#TDDeltaUserDefined"))
insDoc(aux2, gLnk("R", "TDKickFunction", "vars/Time-Dependent.html#TDKickFunction"))
insDoc(aux2, gLnk("R", "TDMomentumTransfer", "vars/Time-Dependent.html#TDMomentumTransfer"))
aux3 = insFld(aux2, gFld("Dipole", "vars/Time-Dependent.html#Time-Dependent::Response::Dipole"))
insDoc(aux3, gLnk("R", "TDPolarization", "vars/Time-Dependent.html#TDPolarization"))
insDoc(aux3, gLnk("R", "TDPolarizationDirection", "vars/Time-Dependent.html#TDPolarizationDirection"))
insDoc(aux3, gLnk("R", "TDPolarizationEquivAxes", "vars/Time-Dependent.html#TDPolarizationEquivAxes"))
insDoc(aux3, gLnk("R", "TDPolarizationWprime", "vars/Time-Dependent.html#TDPolarizationWprime"))
aux2 = insFld(aux1, gFld("TD Output", "vars/Time-Dependent.html#Time-Dependent::TD_Output"))
insDoc(aux2, gLnk("R", "TDExcitedStatesToProject", "vars/Time-Dependent.html#TDExcitedStatesToProject"))
insDoc(aux2, gLnk("R", "TDFloquetDimension", "vars/Time-Dependent.html#TDFloquetDimension"))
insDoc(aux2, gLnk("R", "TDFloquetFrequency", "vars/Time-Dependent.html#TDFloquetFrequency"))
insDoc(aux2, gLnk("R", "TDFloquetSample", "vars/Time-Dependent.html#TDFloquetSample"))
insDoc(aux2, gLnk("R", "TDMultipoleLmax", "vars/Time-Dependent.html#TDMultipoleLmax"))
insDoc(aux2, gLnk("R", "TDOutput", "vars/Time-Dependent.html#TDOutput"))
insDoc(aux2, gLnk("R", "TDOutputComputeInterval", "vars/Time-Dependent.html#TDOutputComputeInterval"))
insDoc(aux2, gLnk("R", "TDProjStateStart", "vars/Time-Dependent.html#TDProjStateStart"))
aux1 = insFld(aux0, gFld("Utilities", "vars/Utilities.html#Utilities::"))
insDoc(aux1, gLnk("R", "Volume", "vars/Utilities.html#Volume"))
aux2 = insFld(aux1, gFld("oct-casida_spectrum", "vars/Utilities.html#Utilities::oct-casida_spectrum"))
insDoc(aux2, gLnk("R", "CasidaSpectrumBroadening", "vars/Utilities.html#CasidaSpectrumBroadening"))
insDoc(aux2, gLnk("R", "CasidaSpectrumEnergyStep", "vars/Utilities.html#CasidaSpectrumEnergyStep"))
insDoc(aux2, gLnk("R", "CasidaSpectrumMaxEnergy", "vars/Utilities.html#CasidaSpectrumMaxEnergy"))
insDoc(aux2, gLnk("R", "CasidaSpectrumMinEnergy", "vars/Utilities.html#CasidaSpectrumMinEnergy"))
insDoc(aux2, gLnk("R", "CasidaSpectrumRotationMatrix", "vars/Utilities.html#CasidaSpectrumRotationMatrix"))
aux2 = insFld(aux1, gFld("oct-center-geom", "vars/Utilities.html#Utilities::oct-center-geom"))
insDoc(aux2, gLnk("R", "AxisType", "vars/Utilities.html#AxisType"))
insDoc(aux2, gLnk("R", "MainAxis", "vars/Utilities.html#MainAxis"))
aux2 = insFld(aux1, gFld("oct-conductivity_spectrum", "vars/Utilities.html#Utilities::oct-conductivity_spectrum"))
insDoc(aux2, gLnk("R", "ConductivityFromForces", "vars/Utilities.html#ConductivityFromForces"))
insDoc(aux2, gLnk("R", "ConductivitySpectrumTimeStepFactor", "vars/Utilities.html#ConductivitySpectrumTimeStepFactor"))
aux2 = insFld(aux1, gFld("oct-convert", "vars/Utilities.html#Utilities::oct-convert"))
insDoc(aux2, gLnk("R", "ConvertEnd", "vars/Utilities.html#ConvertEnd"))
insDoc(aux2, gLnk("R", "ConvertEnergyMax", "vars/Utilities.html#ConvertEnergyMax"))
insDoc(aux2, gLnk("R", "ConvertEnergyMin", "vars/Utilities.html#ConvertEnergyMin"))
insDoc(aux2, gLnk("R", "ConvertEnergyStep", "vars/Utilities.html#ConvertEnergyStep"))
insDoc(aux2, gLnk("R", "ConvertFTMethod", "vars/Utilities.html#ConvertFTMethod"))
insDoc(aux2, gLnk("R", "ConvertFilename", "vars/Utilities.html#ConvertFilename"))
insDoc(aux2, gLnk("R", "ConvertFolder", "vars/Utilities.html#ConvertFolder"))
insDoc(aux2, gLnk("R", "ConvertHow", "vars/Utilities.html#ConvertHow"))
insDoc(aux2, gLnk("R", "ConvertIterateFolder", "vars/Utilities.html#ConvertIterateFolder"))
insDoc(aux2, gLnk("R", "ConvertOutputFilename", "vars/Utilities.html#ConvertOutputFilename"))
insDoc(aux2, gLnk("R", "ConvertOutputFolder", "vars/Utilities.html#ConvertOutputFolder"))
insDoc(aux2, gLnk("R", "ConvertReadSize", "vars/Utilities.html#ConvertReadSize"))
insDoc(aux2, gLnk("R", "ConvertScalarOperation", "vars/Utilities.html#ConvertScalarOperation"))
insDoc(aux2, gLnk("R", "ConvertStart", "vars/Utilities.html#ConvertStart"))
insDoc(aux2, gLnk("R", "ConvertStep", "vars/Utilities.html#ConvertStep"))
insDoc(aux2, gLnk("R", "ConvertSubtract", "vars/Utilities.html#ConvertSubtract"))
insDoc(aux2, gLnk("R", "ConvertSubtractFilename", "vars/Utilities.html#ConvertSubtractFilename"))
insDoc(aux2, gLnk("R", "ConvertSubtractFolder", "vars/Utilities.html#ConvertSubtractFolder"))
aux2 = insFld(aux1, gFld("oct-local_multipoles", "vars/Utilities.html#Utilities::oct-local_multipoles"))
insDoc(aux2, gLnk("R", "LDBaderThreshold", "vars/Utilities.html#LDBaderThreshold"))
insDoc(aux2, gLnk("R", "LDEnd", "vars/Utilities.html#LDEnd"))
insDoc(aux2, gLnk("R", "LDExtraWrite", "vars/Utilities.html#LDExtraWrite"))
insDoc(aux2, gLnk("R", "LDFilename", "vars/Utilities.html#LDFilename"))
insDoc(aux2, gLnk("R", "LDFolder", "vars/Utilities.html#LDFolder"))
insDoc(aux2, gLnk("R", "LDIonicDipole", "vars/Utilities.html#LDIonicDipole"))
insDoc(aux2, gLnk("R", "LDIterateFolder", "vars/Utilities.html#LDIterateFolder"))
insDoc(aux2, gLnk("R", "LDMultipoleLmax", "vars/Utilities.html#LDMultipoleLmax"))
insDoc(aux2, gLnk("R", "LDOutput", "vars/Utilities.html#LDOutput"))
insDoc(aux2, gLnk("R", "LDOutputFormat", "vars/Utilities.html#LDOutputFormat"))
insDoc(aux2, gLnk("R", "LDOverWrite", "vars/Utilities.html#LDOverWrite"))
insDoc(aux2, gLnk("R", "LDRadiiFile", "vars/Utilities.html#LDRadiiFile"))
insDoc(aux2, gLnk("R", "LDRestart", "vars/Utilities.html#LDRestart"))
insDoc(aux2, gLnk("R", "LDRestartFolder", "vars/Utilities.html#LDRestartFolder"))
insDoc(aux2, gLnk("R", "LDStart", "vars/Utilities.html#LDStart"))
insDoc(aux2, gLnk("R", "LDStep", "vars/Utilities.html#LDStep"))
insDoc(aux2, gLnk("R", "LDUpdate", "vars/Utilities.html#LDUpdate"))
insDoc(aux2, gLnk("R", "LDUseAtomicRadii", "vars/Utilities.html#LDUseAtomicRadii"))
insDoc(aux2, gLnk("R", "LocalDomains", "vars/Utilities.html#LocalDomains"))
aux2 = insFld(aux1, gFld("oct-photoelectron_spectrum", "vars/Utilities.html#Utilities::oct-photoelectron_spectrum"))
insDoc(aux2, gLnk("R", "PhotoelectronSpectrumOutput", "vars/Utilities.html#PhotoelectronSpectrumOutput"))
insDoc(aux2, gLnk("R", "PhotoelectronSpectrumResolveStates", "vars/Utilities.html#PhotoelectronSpectrumResolveStates"))
aux2 = insFld(aux1, gFld("oct-propagation_spectrum", "vars/Utilities.html#Utilities::oct-propagation_spectrum"))
insDoc(aux2, gLnk("R", "PropagationSpectrumDampFactor", "vars/Utilities.html#PropagationSpectrumDampFactor"))
insDoc(aux2, gLnk("R", "PropagationSpectrumDampMode", "vars/Utilities.html#PropagationSpectrumDampMode"))
insDoc(aux2, gLnk("R", "PropagationSpectrumEndTime", "vars/Utilities.html#PropagationSpectrumEndTime"))
insDoc(aux2, gLnk("R", "PropagationSpectrumEnergyStep", "vars/Utilities.html#PropagationSpectrumEnergyStep"))
insDoc(aux2, gLnk("R", "PropagationSpectrumMaxEnergy", "vars/Utilities.html#PropagationSpectrumMaxEnergy"))
insDoc(aux2, gLnk("R", "PropagationSpectrumSigmaDiagonalization", "vars/Utilities.html#PropagationSpectrumSigmaDiagonalization"))
insDoc(aux2, gLnk("R", "PropagationSpectrumStartTime", "vars/Utilities.html#PropagationSpectrumStartTime"))
insDoc(aux2, gLnk("R", "PropagationSpectrumTransform", "vars/Utilities.html#PropagationSpectrumTransform"))
insDoc(aux2, gLnk("R", "PropagationSpectrumType", "vars/Utilities.html#PropagationSpectrumType"))
insDoc(aux2, gLnk("R", "SpectrumMethod", "vars/Utilities.html#SpectrumMethod"))
insDoc(aux2, gLnk("R", "SpectrumSignalNoise", "vars/Utilities.html#SpectrumSignalNoise"))
aux2 = insFld(aux1, gFld("oct-test", "vars/Utilities.html#Utilities::oct-test"))
insDoc(aux2, gLnk("R", "TestMaxBlockSize", "vars/Utilities.html#TestMaxBlockSize"))
insDoc(aux2, gLnk("R", "TestMinBlockSize", "vars/Utilities.html#TestMinBlockSize"))
insDoc(aux2, gLnk("R", "TestMode", "vars/Utilities.html#TestMode"))
insDoc(aux2, gLnk("R", "TestRepetitions", "vars/Utilities.html#TestRepetitions"))
insDoc(aux2, gLnk("R", "TestType", "vars/Utilities.html#TestType"))
aux2 = insFld(aux1, gFld("oct-vibrational_spectrum", "vars/Utilities.html#Utilities::oct-vibrational_spectrum"))
insDoc(aux2, gLnk("R", "VibrationalSpectrumTime", "vars/Utilities.html#VibrationalSpectrumTime"))
insDoc(aux2, gLnk("R", "VibrationalSpectrumTimeStepFactor", "vars/Utilities.html#VibrationalSpectrumTimeStepFactor"))
aux2 = insFld(aux1, gFld("oct-xyz-anim", "vars/Utilities.html#Utilities::oct-xyz-anim"))
insDoc(aux2, gLnk("R", "AnimationMultiFiles", "vars/Utilities.html#AnimationMultiFiles"))
insDoc(aux2, gLnk("R", "AnimationSampling", "vars/Utilities.html#AnimationSampling"))
